Learn R Programming

randomGODB (version 1.1)

fractAncest: fractAncest

Description

analysis of fraction of ancestor categories to which a leaf gene maps

Usage

fractAncest(
  genes,
  GOGOA3,
  ontology = "biological_process",
  GOBPCHILDREN,
  GOBPANCESTOR,
  verbose = TRUE
)

Value

returns no values, but has side effect of printing out some results

Arguments

genes

character vector list of gene names

GOGOA3

return value of minimalistGODB::buildGODatabase()

ontology

character c("biological_process","molecular_function","cellular_component")

GOBPCHILDREN

GO.db data set

GOBPANCESTOR

GO.db data set

verbose

Boolean if TRUE print out some information

Examples

Run this code
if (FALSE) {
# GOGOA3.RData is too large to include in the R package
# so I need to load it from a file that is not in the package.
# Since this is in a file in my own file system, I could not
# include this as a regular example in the package.
# This example is given in full detail in the package vignette.
# You can generate GOGOA3.RData using the package 'minimalistGODB'
# or you can retrieve it from https://github.com/barryzee/GO/databases
dir<-"/Users/barryzeeberg/personal/GODB_RDATA/goa_human/"
load(sprintf("%s/%s",dir,"GOGOA3_goa_human.RData"))
ontology<-"biological_process"
genes<-c("CDC45","CELF2")
#fractAncest(genes,GOGOA3,ontology,GO.db::GOBPCHILDREN,GO.db::GOBPANCESTOR)

if (requireNamespace("GO.db", quietly = TRUE)) {
 ch<-GO.db::GOBPCHILDREN
} else {
 stop("Install 'GO.db' from BioConductor to use this function.", call. = FALSE)
}

if (requireNamespace("GO.db", quietly = TRUE)) {
 an<-GO.db::GOBPANCESTOR
} else {
 stop("Install 'GO.db' from BioConductor to use this function.", call. = FALSE)
}

fractAncest(genes,GOGOA3,ontology,ch,an)
}

Run the code above in your browser using DataLab