geneListDistHitters: geneListDistHitters

View source: R/randomGODB.R

geneListDistHittersR Documentation

geneListDistHitters

Description

compute number of GOGOA3 mappings for genes in geneList

Usage

geneListDistHitters(geneList, GOGOA3, ontologies = NULL, verbose = TRUE)

Arguments

geneList

character vector listg of gene names

GOGOA3

return value of minimalistGODB::buildGODatabase()

ontologies

character c("biological_process","molecular_function","cellular_component")

verbose

Boolean if TRUE print out some information

Value

returns no value, but has side effect of printing information

Examples

## Not run: 
# GOGOA3.RData is too large to include in the R package
# so I need to load it from a file that is not in the package.
# Since this is in a file in my own file system, I could not
# include this as a regular example in the package.
# This example is given in full detail in the package vignette.
# You can generate GOGOA3.RData using the package 'minimalistGODB'
# or you can retrieve it from https://github.com/barryzee/GO/databases
dir<-"/Users/barryzeeberg/personal/GODB_RDATA/goa_human/"
load(sprintf("%s/%s",dir,"GOGOA3_goa_human.RData"))
geneList<-GOGOA3$ontologies[["biological_process"]][1:10,"HGNC"]
geneListDistHitters(geneList,GOGOA3)

## End(Not run)


randomGODB documentation built on June 8, 2025, 9:32 p.m.