| hitters | R Documentation |
pick genes of a size range and submit to fractAncest()
hitters(
GOGOA3,
ontology,
hitters,
ngene,
GOBPCHILDREN,
GOBPANCESTOR,
verbose = TRUE
)
GOGOA3 |
return value of minimalistGODB::buildGODatabase() |
ontology |
character c("biological_process","molecular_function","cellular_component") |
hitters |
character c("big","mid","lo","all") designate which portion of gene table to look at |
ngene |
integer number of genes to examine within range of 'hitters' |
GOBPCHILDREN |
GO.db data set |
GOBPANCESTOR |
GO.db data set |
verbose |
Boolean if TRUE print out some information |
returns no values, but has side effect of printing out some information
## Not run:
# GOGOA3.RData is too large to include in the R package
# so I need to load it from a file that is not in the package.
# Since this is in a file in my own file system, I could not
# include this as a regular example in the package.
# This example is given in full detail in the package vignette.
# You can generate GOGOA3.RData using the package 'minimalistGODB'
# or you can retrieve it from https://github.com/barryzee/GO/databases
dir<-"/Users/barryzeeberg/personal/GODB_RDATA/goa_human/"
load(sprintf("%s/%s",dir,"GOGOA3_goa_human.RData"))
hitters(GOGOA3,ontology="biological_process",hitters="all",
5,GO.db::GOBPCHILDREN,GO.db::GOBPANCESTOR)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.