| randomGODB | R Documentation |
driver to construct a randomized version of GOGOA3
randomGODB(GOGOA3, verbose = TRUE)
GOGOA3 |
return value of minimalistGODB::buildGODatabase() |
verbose |
Boolean if TRUE print out some information |
The results of characterizeDB() show that a gene mapping to a leaf node maps to only around 10% of the ancestors. So I do not need to use a more sophisticated method to generate a random database. That is, I do not need to maintain a consistency between leaf and ancestor mappings. Therefore a very simple randomization
simply scrambling the genes in an ontology of GOGOA3 will suffice.
description
## Not run:
# GOGOA3.RData is too large to include in the R package
# so I need to load it from a file that is not in the package.
# Since this is in a file in my own file system, I could not
# include this as a regular example in the package.
# This example is given in full detail in the package vignette.
# You can generate GOGOA3.RData using the package 'minimalistGODB'
# or you can retrieve it from https://github.com/barryzee/GO/databases
dir<-"/Users/barryzeeberg/personal/GODB_RDATA/goa_human/"
load(sprintf("%s/%s",dir,"GOGOA3_goa_human.RData"))
GOGOA3R<-randomGODB(GOGOA3)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.